# Wiki markup

To use this language, use the class "language-wiki".

## Embedded markup

    Paragraphs can be forced in lists by using HTML tags.
    Two line break symbols, <code><nowiki><br /><br /></nowiki></code>, will create the desired effect. So will enclosing all but the first paragraph with <code><nowiki><p>...</p></nowiki></code>

## Headings

    = Header 1 =
    == Header 2 ==
    === Header 3 ===
    ==== Header 4 ====
    ===== Header 5 =====
    ====== Header 6 ======

## Bold and italic

    '''''Both bold and italic'''''
    '''Only bold'''
    ''Only italic''

## Links and Magic links

    [[w:en:Formal_grammar|Formal grammar]]
    [http://www.cl.cam.ac.uk/~mgk25/iso-ebnf.html EBNF help]

    ISBN 1234567890
    ISBN 123456789x
    ISBN      1 2 3-4-5 6789 X
    ISBN 978-9999999999

    RFC 822
    PMID 822

## Magic words and special symbols

    #REDIRECT [[somewhere]]

    {{SITENAME}}
    {{PAGESINCATEGORY:category}}
    {{#dateformat:2009-12-25|mdy}}

    __NOTOC__

    {{!}}

    ~~~ ~~~~ ~~~~~

## Lists

    * Lists are easy to do:
    ** start every line
    * with a star
    ** more stars mean
    *** deeper levels

    # Numbered lists are good
    ## very organized
    ## easy to follow

    ; Definition lists
    ; item : definition
    ; semicolon plus term
    : colon plus definition

    * Or create mixed lists
    *# and nest them
    *#* like this
    *#*; definitions
    *#*: work:
    *#*; apple
    *#*; banana
    *#*: fruits

## Tables

    {|
    |Orange
    |Apple
    |-
    |Bread
    |Pie
    |-
    |Butter
    |Ice cream
    |}

    {|
    |Lorem ipsum dolor sit amet,
    consetetur sadipscing elitr,
    sed diam nonumy eirmod tempor invidunt
    ut labore et dolore magna aliquyam erat,
    sed diam voluptua.

    At vero eos et accusam et justo duo dolores
    et ea rebum. Stet clita kasd gubergren,
    no sea takimata sanctus est Lorem ipsum
    dolor sit amet.
    |
    * Lorem ipsum dolor sit amet
    * consetetur sadipscing elitr
    * sed diam nonumy eirmod tempor invidunt
    |}

    {|
    |  Orange    ||   Apple   ||   more
    |-
    |   Bread    ||   Pie     ||   more
    |-
    |   Butter   || Ice cream ||  and more
    |}

    {|
    ! style="text-align:left;"| Item
    ! Amount
    ! Cost
    |-
    |Orange
    |10
    |7.00
    |-
    |Bread
    |4
    |3.00
    |-
    |Butter
    |1
    |5.00
    |-
    !Total
    |
    |15.00
    |}

    {|
    ! style="text-align:left;"| Item !! style="color:red;"| Amount !! Cost
    |-
    |Orange
    |10
    |7.00
    |-
    | style="text-align:right;"| Bread
    |4
    |3.00
    |-
    |Butter
    |1
    |5.00
    |-
    !Total
    |
    |15.00
    |}

## Known failures

There are certain edge cases where Prism will fail. There are always such cases in every regex-based syntax highlighter. However, Prism dares to be open and honest about them. If a failure is listed here, it doesn’t mean it will never be fixed. This is more of a “known bugs” list, just with a certain type of bug.

### Nested magic words are not supported

    {{#switch:{{PAGENAME}}
    | L'Aquila = No translation
    | L = Not OK
    | L'Aquila = Entity escaping
    | L'Aquila = Numeric char encoding
    }}

### Nesting of bold and italic is not supported

    ''Italic with '''bold''' inside''